You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by se...@apache.org on 2011/11/01 16:23:50 UTC

svn commit: r1196052 - /commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java

Author: sebb
Date: Tue Nov  1 15:23:49 2011
New Revision: 1196052

URL: http://svn.apache.org/viewvc?rev=1196052&view=rev
Log:
Javadoc fix

Modified:
    commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java

Modified: commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java
URL: http://svn.apache.org/viewvc/commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java?rev=1196052&r1=1196051&r2=1196052&view=diff
==============================================================================
--- commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java (original)
+++ commons/proper/net/trunk/src/main/java/org/apache/commons/net/smtp/AuthenticatingSMTPClient.java Tue Nov  1 15:23:49 2011
@@ -49,12 +49,12 @@ public class AuthenticatingSMTPClient ex
     }
 
     /**
      * Overloaded constructor that takes an encoding specification
      * @param encoding The encoding to use
      * @throws NoSuchAlgorithmException
      */
-    public AuthenticatingSMTPClient(String encoding) throws NoSuchAlgorithmException {
-        super(encoding);
+    public AuthenticatingSMTPClient(String protocol) throws NoSuchAlgorithmException {
+        super(protocol);
     }
 
     /***
@@ -49,12 +49,12 @@ public class AuthenticatingSMTPClient ex
 
     /**
-     * Overloaded constructor that takes an encoding specification
-     * @param encoding The encoding to use
+     * Overloaded constructor that takes a protocol specification
+     * @param protocol The encoding to use
      * @throws NoSuchAlgorithmException
      */